@@ -13,7 +13,7 @@ class RemoteIPExpection(Exception):
     pass
 
 
-class RedisSessionHandler(object):
+class RedisSessionStore(object):
     def __init__(self, redis_connection, **options):
         self.options = {
             'key_prefix': 'sid',
